@@ -9,21 +9,21 @@ __all__ = [
     "__version__",
     "_compiled",
     "EmissionInfo",
+    "EventedModel",
     "Signal",
     "SignalGroup",
     "SignalInstance",
     "throttled",
     "debounced",
-    "SignalThrottler",
-    "SignalDebouncer",
 ]
 import os
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
     from types import ModuleType
 
     from . import _group, _signal
+    from ._evented_model import EventedModel
 
     Signal = _signal.Signal
     SignalInstance = _signal.SignalInstance
@@ -63,4 +63,15 @@ else:
     from ._signal import Signal, SignalInstance, _compiled
     from ._throttler import debounced, throttled
 
+
+def __getattr__(name: str) -> Any:
+    if name == "EventedModel":
+        from ._evented_model import EventedModel
+
+        return EventedModel
+    raise AttributeError(  # pragma: no cover
+        f"module {__name__!r} has no attribute {name!r}"
+    )
+
+
 del os, TYPE_CHECKING
